@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP;
 use vars '$VERSION';
-$VERSION = '2.13';
+$VERSION = '2.14';
 
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
@@ -272,7 +272,7 @@ sub _writer_body($)
         }
         elsif(my $type = $part->{type})
         {   $code  = $self->_writer_body_type($args, $part);
-            $label = (unpack_type $type)[1];
+            $label = (unpack_type $part->{name})[1];
         }
         else
         {   error __x"part {name} has neither `element' nor `type' specified"
@@ -310,7 +310,7 @@ sub _writer_body_type($$)
 
     $part->{writer} =
         $self->schemas->compileType
-          ( WRITER => $part->{type}, %$args
+          ( WRITER  => $part->{type}, %$args
           , element => $part->{name}
           , include_namespaces => sub {$_[0] ne $soapenv}
           );
